@@ -28,13 +28,11 @@
 #include <QObject>
 #include <QSize>
 #include <QRectF>
-#include <QPointer>
 #include <QMap>
-#include <boost/scoped_ptr.hpp>
 
 class DocumentPrivate;
 class KUrl;
-class DataStructurePluginInterface;
+class DataStructureBackendInterface;
 class DataStructure;
 class QtScriptBackend;
 class QSvgRenderer;
@@ -43,21 +41,9 @@ class QPointF;
 class ROCSLIB_EXPORT Document : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(qreal left READ left WRITE setLeft)
-    Q_PROPERTY(qreal right READ right WRITE setRight)
-    Q_PROPERTY(qreal top READ top WRITE setTop)
-    Q_PROPERTY(qreal bottom READ bottom WRITE setBottom)
 
 public:
-    enum Border {BorderLeft, BorderBottom, BorderRight, BorderTop};
-
-    explicit Document(const QString &name,
-             qreal left = -200,
-             qreal right = 200,
-             qreal top = -200,
-             qreal bottom = 200,
-             QObject *parent = 0
-            );
+    explicit Document(const QString &name, QObject *parent = 0);
     ~Document();
 
     bool isModified() const;
@@ -76,7 +62,7 @@ public:
      *
      * \param fileUrl path to local file to that document shall be saved
      */
-    void saveAs(const QString& fileUrl);
+    void saveAs(const QString &fileUrl);
 
     /**
      * \return path used for saving
@@ -110,7 +96,7 @@ public:
     /**
      * \return the size of document' (visual) area
      */
-    QRectF size();
+    QRectF sceneRect() const;
 
     /** @brief clear data that only is useful for a type of data structure and that cannot be converted to others from all data structeres of this document.
      * TODO this method should be protected
@@ -120,7 +106,7 @@ public:
     /**
      * \return backend of this document
      */
-    DataStructurePluginInterface * backend() const;
+    DataStructureBackendInterface * backend() const;
 
     /**
      * Set data structure plugin for this document. This function is only safe if the document
@@ -192,6 +178,14 @@ public:
 public Q_SLOTS:
     void setModified(const bool mod = true);
 
+    /**
+     * Updates scene rect according to given position. If \p position lies outside of rect, the rect
+     * is increased. Otherwise, (currently) nothing is done.
+     *
+     * \param position is the new position of the changed data element
+     */
+    void updateSceneRect(const QPointF &position);
+
     /**
      * Add data structure to graph document with name \p name.
      * If no name is given, the name of the used data structure is used.
@@ -223,31 +217,8 @@ public Q_SLOTS:
     void setActiveDataStructure(int index);
     void setActiveDataStructure(DataStructurePtr g);
 
-    void setLeft(qreal leftValue);
-    void setRight(qreal rightValue);
-    void setTop(qreal topValue);
-    void setBottom(qreal buttomValue);
-
-    qreal left() const;
-    qreal top() const;
-    qreal right() const;
-    qreal bottom() const;
-
-    qreal height() const;
-    qreal width() const;
-
-    /**
-     * estimates by looking at all node positions if a resize of the document is necessary.
-     */
-    void resizeDocumentIncrease();
-    void resizeDocumentBorder(Document::Border orientation);
-    void changeMinimalSize(qreal width, qreal height);
-
-    /**
-     * tests if given point is containted at document layer
-     */
-    bool isPointAtDocument(qreal x, qreal y) const;
-    bool isPointAtDocument(const QPointF &point) const;
+    void updateGraphics(DataTypePtr dataType);
+    void updateGraphics(PointerTypePtr pointerType);
 
 Q_SIGNALS:
     void dataStructureCreated(DataStructurePtr g);
@@ -257,14 +228,12 @@ Q_SIGNALS:
     void dataTypeRemoved(int identifier);
     void pointerTypeRemoved(int identifier);
     void nameChanged(QString name);
-    void heightChanged(qreal height);
-    void widthChanged(qreal width);
     void activeDataStructureChanged(DataStructurePtr g);
-    void resized();
+    void sceneRectChanged(const QRectF &);
 
 private:
     // d-pointer
-    const boost::scoped_ptr<DocumentPrivate> d;
+    const QScopedPointer<DocumentPrivate> d;
     Document(const Document&);
     Document& operator=(const Document&);
 };
